PUB High(pin)
{{Set I/O pin to output-high.  Pin will transmit 3.3 V.
  PARAMETERS: pin = I/O pin number
}}                                                                                                      
  outa[pin]~~                                ' equivalent to outa[pin] := 1
  dira[pin]~~
  
PUB Low(pin)
{{Set I/O pin to output-low.  Pin will transmit 0 V.
  PARAMETER: pin = I/O pin number
}}                                                                                                      
  outa[pin]~                                ' equivalent to outa[pin] := 0 
  dira[pin]~~
  
PUB Check(pin) : state
{{Check I/O pin state.  
  PARAMETERS: pin = I/O pin number
  RETURNS: 1 if voltage is above 1.65 V, 0 if below
  Note: If the I/O pin is an output, it retruns whatever state
        the pin has been set to.  If it's an input, it returns
        a value based on the voltage applied to the pin.
}}                                                                                                      
  state := ina[pin]

PUB Dir(pin, direction)
{{Set I/O pin direction.
  PARAMETERS: pin = I/O pin number
              direction = output (1) or input (0)
  Note: All I/O pins default to input when the Propeller boots.
}}
  dira[pin] := direction

PUB Set(pin, state)
{{Set I/O pin output state.  
  PARAMETERS: pin = I/O pin number
              state = high (1) or low (0)
  Note: If the pin is not already set to output, you may want 
  to call the dir method after this one.                          
}}

PUB Toggle(pin)
{{Sets an I/O pin to the opposite of its previous output state.
}}
  ! outa[pin]

PUB Reverse(pin)
{{Sets an I/O pin to the opposite of its previous direction.
  PARAMETERS: pin = I/O pin number
}}
  ! dira[pin]

PUB CheckGroup(last, first) : states
{{Check states of a contiguous group of I/O pins.  
  PARAMETERS: last = last in the group of I/O pins 
              first = first in the group of I/O pins
  RETURNS states: Binary value that corresponds to the
                  output/input pattern of I/O pins.  The 
                  least significant bit contains the direction
                  of the first I/O pin, and successive bit
                  values correspond to successive I/O pin
                  directions, up through the last value. 
  Note: If the I/O pin is an output, it returns whatever state
        the pin has been set to.  If it's an input, it returns
        a value based on the voltage applied to the pin.
}}                                                                                                      
  states := ina[last..first]   

PUB DirGroup(last, first, directions)
{{Set I/O pin direction.
  PARAMETERS: last       = last in the group of I/O pins 
              first      = first in the group of I/O pins
              directions = Binary value that corresponds to
              the I/O pin states (output = 1, input = 0).
              The least significant bit contains the state of
              the first I/O pin, and successive bit values
              correspond to successive I/O pin states, up
              through the last value. 
  Note: All I/O pins default to input when the Propeller boots.
}}
  dira[last..first] := directions

PUB SetGroup(last, first, states)
{{Set states of a contiguous group of I/O pins.  
  PARAMETERS: last = last in the group of I/O pins 
              first = first in the group of I/O pins
              states = binary pattern %last..first
  Note: If the I/O pin is an output, a 1 sets the I/O pin to
  3.3 V; a 0 sets it to 0 V.  
}}
  outa[last..first] := states

PUB ToggleGroup(last, first)
{{Sets a group of I/O pins to states that are opposite of their
previous states.
  PARAMETERS: last = last in the group of I/O pins 
              first = first in the group of I/O pins
}}
  !outa[last..first]

PUB reverseGroup(last, first)
{{Sets a group of I/O pins to directions that are opposite of their
previous settings.
  PARAMETERS: last = last in the group of I/O pins 
              first = first in the group of I/O pins
}}
  !dira[last..first]

  